@@ -203,16 +203,38 @@ class Chemical:
     eos=PengRobinson : GCEOS subclass, optional
         Equation of state class for solving thermodynamic properties.
         Defaults to Peng-Robinson.
+    phase_ref=None : {'s', 'l', 'g'}, optional
+        Reference phase of chemical.
     CAS=None : str, optional
         CAS number of chemical.
+    phase=None: {'s', 'l' or 'g'}, optional
+        Phase to set state of chemical.
+    search_db=True: bool, optional
+        Whether to search the data base for chemical.
+    Cn=None : float or function(T), optional
+        Molar heat capacity model [J/mol] as a function of temperature [K].
+    sigma=None : float or function(T), optional
+        Surface tension model [N/m] as a function of temperature [K].
+    epsilon=None : float or function(T), optional
+        Relative permitivity model [-] as a function of temperature [K].
+    Psat=None : float or function(T), optional
+        Vapor pressure model [N/m] as a function of temperature [K].
+    Hvap=None : float or function(T), optional
+        Heat of vaporization model [J/mol] as a function of temperature [K].
+    V=None : float or function(T, P), optional
+        Molar volume model [mol/m3] as a function of temperature [K] and pressure [Pa].
+    mu=None : float or function(T, P), optional
+        Dynamic viscosity model [Pa*s] as a function of temperature [K] and pressure [Pa].
+    kappa=None : float or function(T, P), optional
+        Thermal conductivity model [W/m/K] as a function of temperature [K] and pressure [Pa].
+    Cp=None : float, optional
+        Constant heat capacity model [J/g].
+    rho=None : float, optional
+        Constant density model [kg/m3].
     default=False : bool, optional
         Whether to default any missing chemical properties such as molar volume,
         heat capacity, surface tension, thermal conductivity, and molecular weight
         to that of water (on a weight basis).
-    phase=None: {'s', 'l' or 'g'}, optional
-        Phase to set state of chemical.
-    search_db=False: bool, optional
-        Whether to search the data base for chemical.
     **data : float or str
         User data (e.g. Tb, formula, etc.).
     
