@@ -6,15 +6,13 @@ from . import thermo_model_handle
 from . import handle_builder
 from . import phase_handle
 from . import units_of_measure
-from . import documenter
 
 __all__ = (*functor.__all__,
            *thermo_model.__all__,
            *thermo_model_handle.__all__,
            *handle_builder.__all__,
            *phase_handle.__all__,
-           *units_of_measure.__all__,
-           *documenter.__all__)
+           *units_of_measure.__all__)
 
 from .functor import *
 from .thermo_model import *
@@ -22,7 +20,6 @@ from .thermo_model_handle import *
 from .handle_builder import *
 from .phase_handle import *
 from .units_of_measure import *
-from .documenter import *
 
 # Set number of digits displayed
 import numpy as np
