@@ -314,10 +314,7 @@ types = {'atoms': 'Dict[str, int]'}
 types['iscyclic_aliphatic'] = types['has_hydroxy'] = 'bool'
 
 # Synonyms
-for i, j in [('ω', 'omega')]:
-    definitions[i] = definitions[j]
-    if j in chemical_units_of_measure:
-        chemical_units_of_measure[i] = chemical_units_of_measure[j]
+definitions['ω'] = definitions['omega']
 
 # Phase properties
 for var in ('mu', 'Cn', 'H', 'S', 'V', 'kappa', 'H_excess', 'S_excess'):
