@@ -89,10 +89,7 @@ class DewPoint:
         Psats = array([i if i > 1e-16 else 1e-16 for i in Psats])
         phi = self.phi(z_norm, T, P)
         x_gamma_pcf = phi * zP / Psats
-        try:
-            self.x = solve_x(x_gamma_pcf, self.gamma, self.pcf, T, self.x)
-        except:
-            self.x = solve_x(x_gamma_pcf, lambda *args: 1, self.pcf, T, self.x)
+        self.x = solve_x(x_gamma_pcf, self.gamma, self.pcf, T, self.x)
         return 1 - self.x.sum()
     
     def _P_error(self, P, T, z_norm, z_over_Psats):
