@@ -43,6 +43,7 @@ from ..base import (InterpolatedTDependentModel,
                     PhaseTHandleBuilder, 
                     thermo_model, 
                     functor)
+from ..utils import load_json
 from .utils import to_nums, CASDataReader
 from .._constants import R, calorie
 from ..functional import polylog2
@@ -129,43 +130,16 @@ read = CASDataReader(__file__, 'Heat Capacity')
 _Poling = read('PolingDatabank.tsv')
 _TRC_gas = read('TRC Thermodynamics of Organic Compounds in the Gas State.tsv')
 _CRC_standard = read('CRC Standard Thermodynamic Properties of Chemical Substances.tsv')
-_PerryI = {}
+_PerryI = load_json(read.folder, 'Perrys Table 2-151.json')
+# Read in a dict of heat capacities of irnorganic and elemental solids.
+# These are in section 2, table 151 in:
+# Green, Don, and Robert Perry. Perry's Chemical Engineers' Handbook,
+# Eighth Edition. McGraw-Hill Professional, 2007.
 
-with open(os.path.join(read.folder, 'Perrys Table 2-151.tsv'), encoding='utf-8') as f:
-    """Read in a dict of heat capacities of irnorganic and elemental solids.
-    These are in section 2, table 151 in:
-    Green, Don, and Robert Perry. Perry's Chemical Engineers' Handbook,
-    Eighth Edition. McGraw-Hill Professional, 2007.
+# Formula:
+# Cn(Cal/mol/K) = Const + Lin*T + Quadinv/T^2 + Quadinv*T^2
 
-    Formula:
-    Cn(Cal/mol/K) = Const + Lin*T + Quadinv/T^2 + Quadinv*T^2
-
-    Phases: c, gls, l, g.
-    """
-    next(f)
-    for line in f:
-        values = to_nums(line.strip('\n').split('\t'))
-        (CASRN, _formula, _phase, _subphase, Const, Lin, Quadinv, Quad, Tmin,
-         Tmax, err) = values
-        if Lin is None:
-            Lin = 0
-        if Quadinv is None:
-            Quadinv = 0
-        if Quad is None:
-            Quad = 0
-        if CASRN in _PerryI and CASRN:
-            a = _PerryI[CASRN]
-            a.update({_phase: {"Formula": _formula, "Phase": _phase,
-                               "Subphase": _subphase, "Const": Const,
-                               "Lin": Lin, "Quadinv": Quadinv, "Quad": Quad,
-                               "Tmin": Tmin, "Tmax": Tmax, "Error": err}})
-            _PerryI[CASRN] = a
-        else:
-            _PerryI[CASRN] = {_phase: {"Formula": _formula, "Phase": _phase,
-                                       "Subphase": _subphase, "Const": Const,
-                                       "Lin": Lin, "Quadinv": Quadinv,
-                                       "Quad": Quad, "Tmin": Tmin,
-                                       "Tmax": Tmax, "Error": err}}
+# Phases: c, gls, l, g.
 
 
 
@@ -255,7 +229,7 @@ def Lastovka_Shaw(T, MW, similarity_variable, iscyclic_aliphatic=False):
 
 @functor(var='H.g')
 def Lastovka_Shaw_Integral(Ta, Tb, MW, similarity_variable, iscyclic_aliphatic=False):
-    term = calculate_Lastovka_Shaw_term(iscyclic_aliphatic, a)
+    term = calculate_Lastovka_Shaw_term(iscyclic_aliphatic, similarity_variable)
     return (Lastovka_Shat_Indefinite_Integral(Tb, MW, similarity_variable, term)
             - Lastovka_Shat_Indefinite_Integral(Ta, MW, similarity_variable, term))
 
@@ -277,7 +251,7 @@ def Lastovka_Shat_Indefinite_Integral(T, MW, similarity_variable, term=None):
 @functor(var='S.g')
 def Lastovka_Shaw_Integral_Over_T(Ta, Tb, MW, similarity_variable,
                                   iscyclic_aliphatic=False):
-    term = calculate_Lastovka_Shaw_term(iscyclic_aliphatic, a)
+    term = calculate_Lastovka_Shaw_term(iscyclic_aliphatic, similarity_variable)
     return (Lastovka_Shaw_Indefinite_Integral_Over_T(Tb, MW, similarity_variable, term)
             - Lastovka_Shaw_Indefinite_Integral_Over_T(Ta, MW, similarity_variable, term))
 
@@ -315,7 +289,6 @@ def TRCCn(T, a0, a1, a2, a3, a4, a5, a6, a7):
     a0,a1,a2,a3,a4,a5,a6,a7 : float
         Regressed coefficients.
     
-    
     Notes
     -----
     The ideal gas heat capacity (Cn.g; J/mol/K) is given by:
