@@ -56,7 +56,7 @@ References
 
 """
 from math import log, exp
-from ..base import sigma, TDependentHandleBuilder, InterpolatedTDependentModel
+from ..base import functor, TDependentHandleBuilder, InterpolatedTDependentModel
 from .utils import CASDataReader
 from .._constants import N_A, k
 from .miscdata import VDI_saturation_dict, VDI_tabular_data
@@ -71,7 +71,7 @@ __all__ = ('REFPROP',
            'Zuo_Stenby',
            'Hakim_Steinberg_Stiel', 
            'Miqueu',
-           'Mersmann_Kind_surface_tension'
+           'Mersmann_Kind'
 )
 
 read = CASDataReader(__file__, 'Interface')
@@ -84,9 +84,20 @@ _VDI_PPDS_11 = read('VDI PPDS surface tensions.tsv')
 
 ### Regressed coefficient-based functions
 
-@sigma(ref='[1]_', method="regression-based REFPROP")
+@functor(var='sigma')
 def REFPROP(T, Tc, sigma0, n0, sigma1=0, n1=0, sigma2=0, n2=0):
     r"""
+    Create a functor of temperature (T; in K) that estimates the surface 
+    tension (sigma; in N/m) of a chemical using the regression-based REFPROP 
+    method, as described in [1]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    sigma0,n0,sigma1,n1,sigma2,n2 : float
+        Regressed coefficients.
+    
     Notes
     -----
     Relatively recent, and most accurate. Function as implemented in [1]_:
@@ -112,9 +123,20 @@ def REFPROP(T, Tc, sigma0, n0, sigma1=0, n1=0, sigma2=0, n2=0):
     invTr = 1. - Tr
     return sigma0*(invTr)**n0 + sigma1*(invTr)**n1 + sigma2*(invTr)**n2
 
-@sigma(ref='[2]_')
+@functor(var='sigma')
 def Somayajulu(T, Tc, a, b, c):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the surface 
+    tension (sigma; in N/m) of a chemical using the Somayajulu method, as 
+    described in [2]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    a,b,c : float
+        Regressed coefficients.
+    
     Notes
     -----
     The surface tension in [2]_ is given by:
@@ -137,13 +159,22 @@ def Somayajulu(T, Tc, a, b, c):
     >>> f(300)
     0.07166386387996757
     
-    '''
+    """
     X = (Tc-T)/Tc
     return (a*X**1.25 + b*X**2.25 + c*X**3.25)/1000.
 
-@sigma(ref="[3]_ [4]_")
+@functor(var='sigma')
 def Jasper(T, a, b):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the surface 
+    tension (sigma; in N/m) of a chemical using the Jasper method, as 
+    described in [3]_ [4]_.
+    
+    Parameters
+    ----------
+    a,b : float
+        Regressed coefficients.
+    
     Notes
     -----
     Calculates surface tension of a fluid given two parameters, a linear
@@ -161,15 +192,28 @@ def Jasper(T, a, b):
     >>> f(298.15)
     0.0220675
     
-    '''
+    """
     return (a - b*(T-273.15))/1000
 
 
 ### CSP methods
 
-@sigma(ref="[5]_")
+@functor(var='sigma')
 def Brock_Bird(T, Tb, Tc, Pc):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the surface 
+    tension (sigma; in N/m) of a chemical using the Brock Bird method, as 
+    described in [5]_.
+    
+    Parameters
+    ----------
+    Tb : float
+        Boiling point temperature [K].
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    
     Notes
     -----
     Calculates air-water surface tension  using the [1]_
@@ -201,7 +245,7 @@ def Brock_Bird(T, Tb, Tc, Pc):
     >>> f(293.15)
     0.032985686413713036
     
-    '''
+    """
     Tbr = Tb/Tc
     Tr = T/Tc
     Pc = Pc/1E5  # Convert to bar
@@ -209,9 +253,21 @@ def Brock_Bird(T, Tb, Tc, Pc):
     sigma = (Pc)**(2/3.)*Tc**(1/3.)*Q*(1-Tr)**(11/9.)
     return sigma/1000  # convert to N/m
 
-@sigma(ref="[6]_")
+@functor(var='sigma')
 def Pitzer(T, Tc, Pc, omega):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the surface 
+    tension (sigma; in N/m) of a chemical using the Pitzer method, as described in [6]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    omega : float
+        Acentric factor [-].
+    
     Notes
     -----
     Calculates air-water surface tension using the correlation derived
@@ -233,16 +289,29 @@ def Pitzer(T, Tc, Pc, omega):
     >>> f(293.)
     0.03458453513446387
     
-    '''
+    """
     Tr = T/Tc
     Pc = Pc/1E5  # Convert to bar
     sigma = Pc**(2/3.0)*Tc**(1/3.0)*(1.86+1.18*omega)/19.05 * (
         (3.75+0.91*omega)/(0.291-0.08*omega))**(2/3.0)*(1-Tr)**(11/9.0)
     return sigma/1000.  # N/m, please
 
-@sigma(ref='[9]_', other_params=['chemicaltype'])
+@functor(var='sigma')
 def Sastri_Rao(T, Tb, Tc, Pc, chemicaltype=None):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the surface 
+    tension (sigma; in N/m) of a chemical using the Sastri Rao method, as
+    described in [9]_.
+    
+    Parameters
+    ----------
+    Tb : float
+        Boiling point temperature [K].
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    
     Other Parameters
     ----------------
     chemicaltype : 'alcohol' or 'acid'
@@ -266,7 +335,7 @@ def Sastri_Rao(T, Tb, Tc, Pc, chemicaltype=None):
     >>> f(293.15)
     0.03234567739694441
     
-    '''
+    """
     if chemicaltype == 'alcohol':
         k, x, y, z, m = 2.28, 0.25, 0.175, 0, 0.8
     elif chemicaltype == 'acid':
@@ -282,9 +351,22 @@ def Sastri_Rao(T, Tb, Tc, Pc, chemicaltype=None):
 def ST_r(ST, Tc, Pc):
     return log(1. + ST/(Tc**(1/3.0)*Pc**(2/3.0)))
 
-@sigma(ref="[10]_")
+@functor(var='sigma')
 def Zuo_Stenby(T, Tc, Pc, omega):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the surface
+    tension (sigma; in N/m) of a chemical using the Zuo Stenby method, as
+    described in [10]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    omega : float
+        Acentric factor [-].
+    
     Notes
     -----
     Calculates air-water surface tension using the reference fluids
@@ -312,7 +394,7 @@ def Zuo_Stenby(T, Tc, Pc, omega):
     >>> f(293.)
     0.03345569011871088    
     
-    '''
+    """
     Tc_1, Pc_1, omega_1 = 190.56, 4599000.0/1E5, 0.012
     Tc_2, Pc_2, omega_2 = 568.7, 2490000.0/1E5, 0.4
     Pc = Pc/1E5
@@ -323,9 +405,24 @@ def Zuo_Stenby(T, Tc, Pc, omega):
     sigma = Tc**(1/3.0)*Pc**(2/3.0)*(exp(sigma_r)-1)
     return sigma/1000  # N/m, please
 
-@sigma(ref='[11]_')
+@functor(var='sigma')
 def Hakim_Steinberg_Stiel(T, Tc, Pc, omega, StielPolar=0):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the surface
+    tension (sigma; in N/m) of a chemical using the Hakim Steinberg Stiel 
+    method, as described in [11]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    omega : float
+        Acentric factor [-].
+    StielPolar : float
+        Regressed coefficient.
+    
     Notes
     -----
     Calculates air-water surface tension using the reference fluids methods
@@ -348,7 +445,7 @@ def Hakim_Steinberg_Stiel(T, Tc, Pc, omega, StielPolar=0):
     >>> f(298.15)
     0.021907902575190447
     
-    '''
+    """
     Q = (0.1574 + 0.359*omega - 1.769*StielPolar - 13.69*StielPolar**2
         - 0.510*omega**2 + 1.298*StielPolar*omega)
     m = (1.210 + 0.5385*omega - 14.61*StielPolar - 32.07*StielPolar**2
@@ -359,9 +456,22 @@ def Hakim_Steinberg_Stiel(T, Tc, Pc, omega, StielPolar=0):
     sigma = sigma/1000.  # convert to N/m
     return sigma
 
-@sigma(ref="[12]_")
+@functor(var='sigma')
 def Miqueu(T, Tc, Vc, omega):
-    r'''
+    r"""
+    Create a functor of temperature (T; in K) that estimates the surface 
+    tension (sigma; in N/m) of a chemical using the Miqueu method, as 
+    described in [12]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Vc : float
+        Critical point volume [m^3/mol].
+    omega : float
+        Acentric factor [-].
+    
     Notes
     -----
     Calculates air-water surface tension using the methods of [1]_.
@@ -385,14 +495,29 @@ def Miqueu(T, Tc, Vc, omega):
     >>> f(300.)
     0.003474099603581931
     
-    '''
+    """
     Vc = Vc*1E6
     t = 1.-T/Tc
     return k*Tc*(N_A/Vc)**(2/3.)*(4.35 + 4.14*omega)*t**1.26*(1+0.19*t**0.5 - 0.25*t)*10000
 
-@sigma(other_params=['n_associated'], ref='[14]_')
-def Mersmann_Kind_surface_tension(T, Tm, Tb, Tc, Pc, n_associated=1):
-    r'''
+@functor(var='sigma')
+def Mersmann_Kind(T, Tm, Tb, Tc, Pc, n_associated=1):
+    r"""
+    Create a functor of temperature (T; in K) that estimates the surface
+    tension (sigma; in N/m) of a chemical using the Mersmann Kind surface
+    tension method, as described in [14]_.
+    
+    Parameters
+    ----------
+    Tm : float
+        Melting point temperature [K].
+    Tb : float
+        Boiling point temperature [K].
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+        
     Other Parameters
     ----------------
     n_associated : int
@@ -421,7 +546,7 @@ def Mersmann_Kind_surface_tension(T, Tm, Tb, Tc, Pc, n_associated=1):
     >>> f(298.15)
     0.016744309508833335
     
-    '''
+    """
     Tr = T/Tc
     sigma_star = ((Tb - Tm)/Tm)**(1/3.)*(6.25*(1. - Tr) + 31.3*(1. - Tr)**(4/3.))
     sigma = sigma_star*(k*Tc)**(1/3.)*(Tm/Tc)*Pc**(2/3.)*n_associated**(-1/3.)
