@@ -9,14 +9,14 @@ __all__ = ('permitivity_handle',
 import numpy as np
 from .utils import CASDataReader
 from .._constants import N_A, epsilon_0, k
-from ..base import TDependentHandleBuilder, epsilon
+from ..base import TDependentHandleBuilder, functor
 
 read = CASDataReader(__file__, 'Electrolytes')
 
 #: [CASDataSource] Permitivity data
 permittivity_data_CRC = read('Permittivity (Dielectric Constant) of Liquids.tsv')
 
-@epsilon
+@functor(var='epsilon')
 def IAPWS_Permittivity(T, Vl,
                        # Actual molecular dipole moment of water, in C*m
                        dipole = 6.138E-30,
@@ -43,8 +43,18 @@ def IAPWS_Permittivity(T, Vl,
     B = N_A*polarizability*(rhom)/3./epsilon_0
     return (1. + A + 5.*B + (9. + 2.*A + 18.*B + A**2 + 10.*A*B + 9.*B**2)**0.5)/(4. - 4.*B)
 
-@epsilon(doc="auto-doc")
+@functor(var='epsilon')
 def CRC(T, a, b, c, d):
+    r"""
+    Create a functor of temperature (T; in K) that estimates the relative
+    permittivity (epsilon) of a chemical using the CRC method.
+    
+    Parameters
+    ----------
+    a,b,c,d : float
+        Regressed coefficients.
+
+    """
     return a + b*T + c*T**2 + d*T**3
 
 @TDependentHandleBuilder('epsilon')
