@@ -64,17 +64,15 @@ import flexsolve as flx
 from scipy.interpolate import interp2d
 from ..base import (InterpolatedTDependentModel, 
                     ThermoModelHandle,
-                    TDependentModel,
                     TPDependentHandleBuilder, 
                     PhaseTPHandleBuilder, 
-                    kappa)
+                    functor)
 from .._constants import R, N_A, k
 from math import log, exp
 from .utils import CASDataReader
 from ..functional import horner_polynomial
 from .miscdata import VDI_saturation_dict, VDI_tabular_data
-from .dippr import DIPPR_EQ100, DIPPR_EQ102
-from collections.abc import Iterable
+from .dippr import DIPPR_EQ100
 
 __all__ = ('thermal_conductivity_handle',
            'Sheffy_Johnson', 
@@ -83,7 +81,7 @@ __all__ = ('thermal_conductivity_handle',
            'Gharagheizi_liquid',
            'Nicola', 
            'Bahadori_liquid', 
-           'Mersmann_Kind_thermal_conductivity_liquid',
+           'Mersmann_Kind_liquid',
            'DIPPR9G', 
            'Missenard', 
            'Eucken', 
@@ -108,9 +106,20 @@ _VDI_PPDS_9 = read('VDI PPDS Thermal conductivity of saturated liquids.tsv')
 _VDI_PPDS_10 = read('VDI PPDS Thermal conductivity of gases.tsv')
 ### Purely CSP Methods - Liquids
 
-@kappa.l(ref='[1]_')
+@functor(var='kappa.l')
 def Sheffy_Johnson(T, MW, Tm):
     r"""
+    Create a functor of temperature (T; in K) that estimates the liquid 
+    thermal conductivity (kappa.l; in W/m/K) of a chemical using the Sheffy 
+    Johnson method, as described in [1]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    Tm : float
+        Melting point temperature [K].
+    
     Notes
     -----
     Calculates the thermal conductivity of a liquid as a function of
@@ -132,9 +141,22 @@ def Sheffy_Johnson(T, MW, Tm):
     """
     return 1.951*(1 - 0.00126*(T - Tm))/(Tm**0.216*MW**0.3)
 
-@kappa.l(ref='[4]_')
+@functor(var='kappa.l')
 def Sato_Riedel(T, MW, Tb, Tc):
     r"""
+    Create a functor of temperature (T; in K) that estimates the liquid
+    thermal conductivity (kappa.l; in W/m/K) of a chemical using the Sato 
+    Riedel method, as described in [4]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    Tb : float
+        Boiling point temperature [K].
+    Tc : float
+        Critical point temperature [K].
+    
     Notes
     -----
     Calculates the thermal conductivity of a liquid as a function of
@@ -160,9 +182,18 @@ def Sato_Riedel(T, MW, Tb, Tc):
     Tbr = Tb/Tc
     return 1.1053*(3. + 20.*(1 - Tr)**(2/3.))*MW**-0.5/(3. + 20.*(1 - Tbr)**(2/3.))
 
-@kappa.l(ref='[5]_')
+@functor(var='kappa.l')
 def Lakshmi_Prasad(T, MW):
     r"""
+    Create a functor of temperature (T; in K) that estimates the liquid 
+    thermal conductivity (kappa.l; in W/m/K) of a chemical using the 
+    Lakshmi Prasad method, as described in [5]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    
     Notes
     -----
     Estimates thermal conductivity of pure liquids as a function of
@@ -193,9 +224,24 @@ def Tmax_Lakshmi_Prasad(MW):
     T_max = flx.aitken_secant(Lakshmi_Prasad.function, 298.15, args=(MW,))
     return T_max - 10 # As an extra precaution
 
-@kappa.l(ref='[6]_')
+@functor(var='kappa.l')
 def Gharagheizi_liquid(T, MW, Tb, Pc, omega):
     r"""
+    Create a functor of temperature (T; in K) that estimates the liquid 
+    thermal conductivity (kappa.l; in W/m/K) of a chemical using the 
+    Gharagheizi liquid method, as described in [6]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    Tb : float
+        Boiling point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    omega : float
+        Acentric factor [-].
+    
     Notes
     -----
     Estimates the thermal conductivity of a liquid as a function of
@@ -230,9 +276,24 @@ def Gharagheizi_liquid(T, MW, Tb, Pc, omega):
         + 3.9287*MW**4*B**-4 + A*B**-8)
 
 
-@kappa.l(ref='[7]_')
+@functor(var='kappa.l')
 def Nicola(T, MW, Tc, Pc, omega):
     r"""
+    Create a functor of temperature (T; in K) that estimates the liquid 
+    thermal conductivity (kappa.l; in W/m/K) of a chemical using the Nicola 
+    method, as described in [7]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    omega : float
+        Acentric factor [-].
+    
     Notes
     -----
     Estimates the thermal conductivity of a liquid as a function of
@@ -258,9 +319,18 @@ def Nicola(T, MW, Tc, Pc, omega):
     Pc = Pc/1E5
     return 0.5147*(-0.2537*Tr + 0.0017*Pc + 0.1501*omega + (1./MW)**0.2999)
 
-@kappa.l(ref='[8]_')
+@functor(var='kappa.l')
 def Bahadori_liquid(T, MW):
     r"""
+    Create a functor of temperature (T; in K) that estimates the liquid
+    thermal conductivity (kappa.l; in W/m/K) of a chemical using the Bahadori
+    liquid method, as described in [8]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    
     Notes
     -----
     Estimates the thermal conductivity of parafin liquid hydrocarbons.
@@ -300,9 +370,24 @@ def Bahadori_liquid(T, MW):
     d = A[3] + B[3]*X + C[3]*X**2 + D[3]*X**3
     return a + b*Y + c*Y**2 + d*Y**3
 
-@kappa.l(ref='[9]_')
-def Mersmann_Kind_thermal_conductivity_liquid(T, MW, Tc, Vc, atoms):
+@functor(var='kappa.l')
+def Mersmann_Kind_liquid(T, MW, Tc, Vc, atoms):
     r"""
+    Create a functor of temperature (T; in K) that estimates the liquid 
+    thermal conductivity (kappa.l; in W/m/K) of a chemical using the Mersmann
+    Kind method, as described in [9]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    Tc : float
+        Critical point temperature [K].
+    Vc : float
+        Critical point volume [m^3/mol].
+    atoms : Dict[str, int]
+        Atom-count pairs [-].
+    
     Notes
     -----
     Estimates the thermal conductivity of organic liquid substances
@@ -322,7 +407,7 @@ def Mersmann_Kind_thermal_conductivity_liquid(T, MW, Tc, Vc, atoms):
     --------
     Dodecane at 400 K:
         
-    >>> f = Mersmann_Kind_thermal_conductivity_liquid(170.33484, 658.0, 
+    >>> f = Mersmann_Kind_liquid(170.33484, 658.0, 
     ... 0.000754, {'C': 12, 'H': 26})
     >>> f(400)
     0.08952713798442789
@@ -337,9 +422,22 @@ def Mersmann_Kind_thermal_conductivity_liquid(T, MW, Tc, Vc, atoms):
 
 ### Thermal Conductivity of Dense Liquids
 
-@kappa.l(ref='[11]_')
+@functor(var='kappa.l')
 def DIPPR9G(T, P, Tc, Pc, k_l):
     r"""
+    Create a functor of temperature (T; in K) and pressure (P; in Pa) that 
+    estimates the liquid thermal conductivity (kappa.l; in W/m/K) of a 
+    chemical using the DIPPR9G method, as described in [11]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    k_l : float
+        Regressed coefficient.
+    
     Notes
     -----
     Adjusts for pressure. the thermal conductivity of a liquid using an
@@ -377,9 +475,22 @@ Qs_Missenard = np.array([[0.036, 0.038, 0.038, 0.038, 0.038, 0.038],
                          [0.012, 0.0165, 0.017, 0.019, 0.020, 0.020]])
 Qfunc_Missenard = interp2d(Prs_Missenard, Trs_Missenard, Qs_Missenard)
 
-@kappa.l(ref='[12]_')
+@functor(var='kappa.l')
 def Missenard(T, P, Tc, Pc, k_l):
     r"""
+    Create a functor of temperature (T; in K) and pressure (P; in Pa) 
+    that estimates the liquid thermal conductivity (kappa.l; in W/m/K)
+    of a chemical using the Missenard method, as described in [12]_.
+    
+    Parameters
+    ----------
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    k_l : float
+        Regressed coefficient.
+        
     Notes
     -----
     Adjusts for pressure. the thermal conductivity of a liquid using an
@@ -447,9 +558,22 @@ def thermal_conductivity_liquid_handle(handle, CAS, MW, Tm, Tb, Tc, Pc, omega):
 
 ### Thermal Conductivity of Gases
 
-@kappa.g(ref='[13]_')
+@functor(var='kappa.g')
 def Eucken(T, MW, Cn, mu_g):
     r"""
+    Create a functor of temperature (T; in K) that estimates the gas thermal 
+    conductivity (kappa.g; in W/m/K) of a chemical using the Eucken method, 
+    as described in [13]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    Cn : float
+        Molar heat capacity [J/mol/K].
+    mu_g : float
+        Gas hydrolic viscosity [-].
+    
     Notes
     -----
     Estimates the thermal conductivity of a gas as a function of
@@ -479,9 +603,22 @@ def Eucken(T, MW, Cn, mu_g):
     MW = MW/1000.
     return (1. + 9/4./(Cv/R))*mu_g*Cv/MW
 
-@kappa.g(ref='[13]_')
+@functor(var='kappa.g')
 def Eucken_modified(T, MW, Cn, mu):
     r"""
+    Create a functor of temperature (T; in K) that estimates the gas 
+    thermal conductivity (kappa.g; in W/m/K) of a chemical using the 
+    Eucken modified method, as described in [13]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    Cn : float
+        Molar heat capacity [J/mol/K].
+    mu : float
+        Hydrolic viscosity [Pa*s].
+    
     Notes
     -----
     Estimates the thermal conductivity of a gas as a function of
@@ -509,7 +646,7 @@ def Eucken_modified(T, MW, Cn, mu):
     MW = MW/1000.
     return (1.32 + 1.77/(Cv/R))*mu*Cv/MW
 
-@kappa.g
+@functor(var='kappa.g')
 def DIPPR9B_linear(T, MW, Cn, mu, Tc):
     if callable(Cn): Cn = Cn(T)
     if callable(mu): mu = mu.at_T(T)
@@ -517,23 +654,40 @@ def DIPPR9B_linear(T, MW, Cn, mu, Tc):
     Tr = T/Tc
     return mu/MW*(1.30*Cv + 14644 - 2928.80/Tr)
 
-@kappa.g    
+@functor(var='kappa.g')    
 def DIPPR9B_monoatomic(T, MW, Cn, mu):
     if callable(Cn): Cn = Cn(T)
     if callable(mu): mu = mu.at_T(T)
     Cv = 1000 * (Cn - R) # J/mol/K to J/kmol/K
     return 2.5*mu*Cv/MW
 
-@kappa.g
+@functor(var='kappa.g')
 def DIPPR9B_nonlinear(T, MW, Cn, mu):
     if callable(Cn): Cn = Cn(T)
     if callable(mu): mu = mu.at_T(T)
     Cv = 1000 * (Cn - R) # J/mol/K to J/kmol/K
     return mu/MW*(1.15*Cv + 16903.36)
 
-@kappa.g(ref='[14]_')
+@functor(var='kappa.g')
 def Chung(T, MW, Tc, omega, Cn, mu):
     r"""
+    Create a functor of temperature (T; in K) that estimates the gas thermal
+    conductivity (kappa.g; in W/m/K) of a chemical using the Chung method, 
+    as described in [14]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    Tc : float
+        Critical point temperature [K].
+    omega : float
+        Acentric factor [-].
+    Cn : float
+        Molar heat capacity [J/mol/K].
+    mu : float
+        Hydrolic viscosity [Pa*s].
+    
     Notes
     -----
     Estimates the thermal conductivity of a gas as a function of
@@ -573,9 +727,28 @@ def Chung(T, MW, Tc, omega, Cn, mu):
                       /(0.6366 + beta*Z + 1.061*alpha*beta))
     return 3.75*psi*R/MW*mu
 
-@kappa.g(ref='[13]_ [15]_')
+@functor(var='kappa.g')
 def Eli_Hanley(T, MW, Tc, Vc, Zc, omega, Cn):
     r"""
+    Create a functor of temperature (T; in K) that estimates the gas thermal 
+    conductivity (kappa.g; in W/m/K) of a chemical using the Eli Hanley 
+    method, as described in [13]_ [15]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    Tc : float
+        Critical point temperature [K].
+    Vc : float
+        Critical point volume [m^3/mol].
+    Zc : float
+        Critical compressibility [-].
+    omega : float
+        Acentric factor [-].
+    Cn : float
+        Molar heat capacity [J/mol/K].
+    
     Notes
     -----
     Estimates the thermal conductivity of a gas as a function of
@@ -640,9 +813,24 @@ def Eli_Hanley(T, MW, Tc, Vc, Zc, omega, Cn):
     ks = k0*H
     return ks + etas/(MW/1000.)*1.32*(Cv - 1.5*R)
 
-@kappa.g(ref='[6]_')
+@functor(var='kappa.g')
 def Gharagheizi_gas(T, MW, Tb, Pc, omega):
     r"""
+    Create a functor of temperature (T; in K) that estimates the gas thermal
+    conductivity (kappa.g; in W/m/K) of a chemical using the Gharagheizi gas 
+    method, as described in [6]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    Tb : float
+        Boiling point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    omega : float
+        Acentric factor [-].
+    
     Notes
     -----
     Estimates the thermal conductivity of a gas as a function of
@@ -676,9 +864,18 @@ def Gharagheizi_gas(T, MW, Tb, Pc, omega):
     A = (2*omega + T - T*(2*omega + 3.2825)/Tb + 3.2825)/(0.1*MW*Pc*T) * (3.9752*omega + 0.1*Pc + 1.9876*B + 6.5243)**2
     return 7.9505E-4 + 3.989E-5*T - 5.419E-5*MW + 3.989E-5*A
 
-@kappa.g(ref='[16]_')
+@functor(var='kappa.g')
 def Bahadori_gas(T, MW):
     r"""
+    Create a functor of temperature (T; in K) that estimates the gas thermal 
+    conductivity (kappa.g; in W/m/K) of a chemical using the Bahadori gas 
+    method, as described in [16]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    
     Notes
     -----
     Estimates the thermal conductivity of hydrocarbons gases at low P.
@@ -718,9 +915,30 @@ def Bahadori_gas(T, MW):
 
 ### Thermal Conductivity of dense gases
 
-@kappa.g(ref='[17]_')
+@functor(var='kappa.g')
 def Stiel_Thodos_dense(T,P, MW, Tc, Pc, Vc, Zc, V_g, k_g):
     r"""
+    Create a functor of temperature (T; in K) and pressure (P; in Pa) that 
+    estimates the gas thermal conductivity (kappa.g; in W/m/K) of a chemical
+    using the Stiel Thodos dense method, as described in [17]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    Tc : float
+        Critical point temperature [K].
+    Pc : float
+        Critical point pressure [Pa].
+    Vc : float
+        Critical point volume [m^3/mol].
+    Zc : float
+        Critical compressibility [-].
+    V_g : float
+        Gas molar volume [-].
+    k_g : float
+        Regressed coefficient.
+    
     Notes
     -----
     Estimates the thermal conductivity of a gas at high pressure as a
@@ -768,9 +986,30 @@ def Stiel_Thodos_dense(T,P, MW, Tc, Pc, Vc, Zc, V_g, k_g):
     k_g = k_g + diff
     return k_g
 
-@kappa.g(ref='[13]_ [15]_')
+@functor(var='kappa.g')
 def Eli_Hanley_dense(T, P, MW, Tc, Vc, Zc, omega, Cn, V_g):
     r"""
+    Create a functor of temperature (T; in K) and pressure (P; in Pa) that 
+    estimates the gas thermal conductivity (kappa.g; in W/m/K) of a chemical 
+    using the Eli Hanley dense method, as described in [13]_ [15]_.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    Tc : float
+        Critical point temperature [K].
+    Vc : float
+        Critical point volume [m^3/mol].
+    Zc : float
+        Critical compressibility [-].
+    omega : float
+        Acentric factor [-].
+    Cn : float
+        Molar heat capacity [J/mol/K].
+    V_g : float
+        Gas molar volume [-].
+    
     Notes
     -----
     Estimates the thermal conductivity of a gas at high pressure as a
@@ -887,9 +1126,32 @@ def Eli_Hanley_dense(T, P, MW, Tc, Vc, Zc, omega, Cn, V_g):
     k = ks + etas/(MW/1000.)*1.32*(Cvm-3*R/2.)
     return k
 
-@kappa.g(other_params=['association'])
+@functor(var='kappa.g')
 def Chung_dense(T, P, MW, Tc, Vc, omega, Cn, V_g, mu_g, dipole, association=0):
     r"""
+    Create a functor of temperature (T; in K) and pressure (P; in Pa) that 
+    estimates the gas thermal conductivity (kappa.g; in W/m/K) of a chemical 
+    using the Chung dense method.
+    
+    Parameters
+    ----------
+    MW : float
+        Molecular weight [g/mol].
+    Tc : float
+        Critical point temperature [K].
+    Vc : float
+        Critical point volume [m^3/mol].
+    omega : float
+        Acentric factor [-].
+    Cn : float
+        Molar heat capacity [J/mol/K].
+    V_g : float
+        Gas molar volume [-].
+    mu_g : float
+        Gas hydrolic viscosity [-].
+    dipole : float
+        Dipole momment [Debye].
+    
     Other Parameters
     ----------------
     association : float, optional
