@@ -17,6 +17,7 @@ from . import var_utils
 from . import registry
 from . import colors
 from . import plot_utils
+from . import load_utils
 
 __all__ = (*name_utils.__all__,
            *pickle_utils.__all__,
@@ -30,6 +31,7 @@ __all__ = (*name_utils.__all__,
            *registry.__all__,
            *colors.__all__,
            *plot_utils.__all__,
+           *load_utils.__all__,
 )
 
 from .name_utils import *
@@ -43,4 +45,5 @@ from .assert_utils import *
 from .var_utils import *
 from .registry import *
 from .colors import *
-from .plot_utils import *
\ No newline at end of file
+from .plot_utils import *
+from .load_utils import *
\ No newline at end of file
