@@ -40,3 +40,10 @@ def repr_listed_values(values):
         return ", ".join(values) + ' and ' + last
     else:
         return last
+
+def repr_obj(obj):
+    return f"{type(obj).__name__}({repr_kwargs(obj.__dict__, start='')})"
+
+
+
+
